@@ -475,7 +475,6 @@ class AnalyseAP:
                 area = self.g.get_rectangle_cercle_area(
                     rect, m, r, leftBound, rightBound
                 )
-            #                print area,leftBound,rightBound
             else:
                 area = bbox[0][1] ** 2
         return area
@@ -963,33 +962,40 @@ class AnalyseAP:
 
     def build_grid(
         self,
-        bb,
         forceBuild=True,
     ):
         t1 = time()
         gridFileIn = None
         gridFileOut = None
         self.env.buildGrid(
-            boundingBox=bb,
             gridFileIn=gridFileIn,
             rebuild=forceBuild,
             gridFileOut=gridFileOut,
             previousFill=False,
         )
-
         t2 = time()
         gridTime = t2 - t1
         print("time to Build Grid", gridTime)
 
     def pack(
-        self, seed=20, vTestid=3, vAnalysis=0, fbox_bb=None, show_plotly_plot=True
+        self,
+        seed=20,
+        vTestid=3,
+        vAnalysis=0,
+        fbox_bb=None,
+        show_plotly_plot=True,
+        show_grid_spheres=False,
     ):
         if show_plotly_plot:
             self.plotly.update_title(self.env.placeMethod)
 
         t1 = time()
         self.env.pack_grid(
-            seedNum=seed, vTestid=vTestid, vAnalysis=vAnalysis, fbox=fbox_bb
+            seedNum=seed,
+            vTestid=vTestid,
+            vAnalysis=vAnalysis,
+            fbox=fbox_bb,
+            show_grid_spheres=show_grid_spheres,
         )
         t2 = time()
         print("time to run pack_grid", self.env.placeMethod, t2 - t1)
@@ -1130,8 +1136,7 @@ class AnalyseAP:
         rdf=True,
         render=False,
         plot=True,
-        show_plotly_plot=True,
-        twod=True,
+        show_grid=True,
         fbox_bb=None,
         use_file=True,
         seeds_i=None,
@@ -1159,7 +1164,6 @@ class AnalyseAP:
         total_positions = []
         total_distances = []
         total_angles = []
-        self.bbox = bbox
         angles = None
         rebuild = True
         for seed_index in range(n):
@@ -1173,15 +1177,16 @@ class AnalyseAP:
             self.env.resultfile = basename
             seed = seeds_i[seed_index]  # int(time())
             self.build_grid(
-                bbox,
                 forceBuild=rebuild,
             )
+            two_d = self.env.is_two_d()
             self.pack(
                 seed=seed,
                 vTestid=seed_index,
                 vAnalysis=1,
                 fbox_bb=fbox_bb,
-                show_plotly_plot=show_plotly_plot,
+                show_plotly_plot=(show_grid and two_d),
+                show_grid_spheres=(show_grid and not two_d),
             )
             self.center = self.env.grid.getCenter()
             if render:
@@ -1189,7 +1194,7 @@ class AnalyseAP:
                 self.helper.render(basename + ".jpg", 640, 480)
                 self.helper.write(basename + ".c4d", [])
             if rdf:
-                if plot and twod:
+                if plot and two_d:
                     width = 1000.0  # should be the boundary here ?
                     fig = pyplot.figure()
                     ax = fig.add_subplot(111)
@@ -1198,6 +1203,14 @@ class AnalyseAP:
                 d = {}
                 if r:
                     for ingr in r.ingredients:
+                        if ingr.color is not None:
+                            color = (
+                                ingr.color
+                                if ingr.color[0] <= 1
+                                else numpy.array(ingr.color) / 255
+                            )
+                        else:
+                            color = None
                         if ingr.name not in distances:
                             distances[ingr.name] = []
                             ingrpositions[ingr.name] = []
@@ -1234,14 +1247,14 @@ class AnalyseAP:
                             total_positions.extend(ingrpos)
                             total_distances.extend(d)
 
-                        if plot and twod:
+                        if plot and two_d:
                             for i, p in enumerate(ingrpos):
                                 ax.add_patch(
                                     Circle(
                                         (p[0], p[1]),
                                         ingr.encapsulatingRadius,
                                         edgecolor="black",
-                                        facecolor=ingr.color,
+                                        facecolor=color,
                                     )
                                 )
                                 #  Plot "image" particles to verify that periodic boundary conditions are working
@@ -1252,7 +1265,7 @@ class AnalyseAP:
                                             Circle(
                                                 (p[0] + width, p[1]),
                                                 r,
-                                                facecolor=ingr.color,
+                                                facecolor=color,
                                             )
                                         )
                                     elif p[0] > (width - r):
@@ -1260,7 +1273,7 @@ class AnalyseAP:
                                             Circle(
                                                 (p[0] - width, p[1]),
                                                 r,
-                                                facecolor=ingr.color,
+                                                facecolor=color,
                                             )
                                         )
                                     if p[1] < r:
@@ -1268,7 +1281,7 @@ class AnalyseAP:
                                             Circle(
                                                 (p[0], p[1] + width),
                                                 r,
-                                                facecolor=ingr.color,
+                                                facecolor=color,
                                             )
                                         )
                                     elif p[1] > (width - r):
@@ -1276,7 +1289,7 @@ class AnalyseAP:
                                             Circle(
                                                 (p[0], p[1] - width),
                                                 r,
-                                                facecolor=ingr.color,
+                                                facecolor=color,
                                             )
                                         )
                                 if i == 0:  # len(ingrpos)-1:
@@ -1299,7 +1312,7 @@ class AnalyseAP:
                                                     (pt[0], pt[1]),
                                                     ingr.minRadius,
                                                     edgecolor="black",
-                                                    facecolor=ingr.color,
+                                                    facecolor=color,
                                                 )
                                             )
                 for o in self.env.compartments:
@@ -1328,7 +1341,7 @@ class AnalyseAP:
                                 ingrpositions[ingr.name].extend(ingrpos)
                                 total_positions.extend(ingrpos)
                                 total_distances.extend(d)
-                            if plot and twod:
+                            if plot and two_d:
                                 for p in ingrpos:
                                     ax.add_patch(
                                         Circle(
@@ -1363,7 +1376,7 @@ class AnalyseAP:
                                 ingrpositions[ingr.name].extend(ingrpos)
                                 total_positions.extend(ingrpos)
                                 total_distances.extend(d)
-                            if plot and twod:
+                            if plot and two_d:
                                 for p in ingrpos:
                                     ax.add_patch(
                                         Circle(
@@ -1387,7 +1400,7 @@ class AnalyseAP:
                         output + os.sep + "_angleIngr_" + str(seed_index) + ".json",
                         anglesingr,
                     )
-                if plot and twod:
+                if plot and two_d:
                     ax.set_aspect(1.0)
                     pyplot.axhline(y=bbox[0][1], color="k")
                     pyplot.axhline(y=bbox[1][1], color="k")
@@ -1423,7 +1436,7 @@ class AnalyseAP:
         self.env.basename = basename
         self.env.occurences = occurences
         self.env.angles = total_angles
-        if plot and twod:
+        if plot and two_d:
             self.env.loopThroughIngr(self.axis_distribution)
             self.env.loopThroughIngr(self.occurence_distribution)
             self.axis_distribution_total(total_positions)
