@@ -43,8 +43,6 @@ from math import ceil, floor
 from random import randrange
 import cellpack.autopack as autopack
 from cellpack.autopack.ldSequence import cHaltonSequence3
-from cellpack.mgl_tools.RAPID import RAPIDlib
-from cellpack.mgl_tools.bhtree import bhtreelib
 
 
 # Kevin Grid point class
@@ -137,11 +135,10 @@ class BaseGrid:
         return nbFreePoints
 
     def __init__(
-        self, boundingBox=([0, 0, 0], [0.1, 0.1, 0.1]), space=1, setup=True, lookup=0
+        self, boundingBox=([0, 0, 0], [0.1, 0.1, 0.1]), spacing=20, setup=True, lookup=0
     ):
         self.log = logging.getLogger("grid")
         self.log.propagate = False
-
         if None in boundingBox[0] or None in boundingBox[1]:
             boundingBox = ([0, 0, 0], [1000, 1000, 1000])
         # a grid is attached to an environnement
@@ -151,7 +148,7 @@ class BaseGrid:
         # to. The id is an integer where 0 is the Histological Volume, and +i is
         # the surface of compartment i and -i is the interior of compartment i
         # in the list self. compartments
-        self.gridPtId = []
+        self.compartment_ids = []
         # will be a list of indices into 3D of compartment
         # of points that have not yet been used by the fill algorithm
         # entries are removed from this list as grid points are used up
@@ -165,7 +162,7 @@ class BaseGrid:
         self.distToClosestSurf = []
         self.distToClosestSurf_store = []
         self.diag = self.getDiagonal()
-        self.gridSpacing = space  # * 1.1547#cubic grid with a diagonal spacing equal to that smallest packing radius
+        self.gridSpacing = spacing  # #cubic grid with a diagonal spacing equal to that smallest packing radius
         self.nbGridPoints = None
         self.nbSurfacePoints = 0
         self.gridVolume = 0  # will be the total number of grid points
@@ -178,7 +175,7 @@ class BaseGrid:
         # this are specific for each compartment
         self.aInteriorGrids = []
         self.aSurfaceGrids = []
-        # bhtree
+        # Treee
         self.surfPtsBht = None
         self.ijkPtIndice = []
         self.filename = None  # used for storing before fill so no need rebuild
@@ -190,17 +187,14 @@ class BaseGrid:
         self.center = None
         self.backup = None
         if setup:
-            self.setup(self.boundingBox, space)
+            self.setup(self.boundingBox)
             # use np.roll to have periodic condition
             # what about collision ?
 
-    def setup(self, boundingBox, space):
+    def setup(self, boundingBox):
         # TODO : verify the gridSpacing calculation / setup after reading the recipe
-        if space == 0:
-            space = 20
-        self.gridSpacing = space  # * 1.1547
-        self.boundingBox = boundingBox
 
+        self.boundingBox = boundingBox
         if self.lookup == 0:
             self.create3DPointLookupCover()
         elif self.lookup == 1:
@@ -213,8 +207,8 @@ class BaseGrid:
 
         self.getDiagonal()
         self.nbSurfacePoints = 0
-        self.log.info("SETUP BASE GRID %d %d", self.gridVolume, self.gridSpacing)
-        self.gridPtId = numpy.zeros(self.gridVolume, "i")  # [0]*nbPoints
+        self.log.info(f"SETUP BASE GRID {self.gridVolume} {self.gridSpacing}")
+        self.compartment_ids = numpy.zeros(self.gridVolume, "i")  # [0]*nbPoints
         # self.distToClosestSurf = [self.diag]*self.gridVolume#surface point too?
         self.distToClosestSurf = (
             numpy.ones(self.gridVolume) * self.diag
@@ -222,11 +216,11 @@ class BaseGrid:
         self.freePoints = list(range(self.gridVolume))
         self.nbFreePoints = len(self.freePoints)
         self.log.info(
-            "Lookup: %d, bounding box: %r, gridSpacing %r, length gridPtId %r",
+            "Lookup: %d, bounding box: %r, gridSpacing %r, length compartment_ids %r",
             self.lookup,
             boundingBox,
             self.gridSpacing,
-            len(self.gridPtId),
+            len(self.compartment_ids),
         )
         self.setupBoundaryPeriodicity()
         return self.gridSpacing
@@ -236,8 +230,6 @@ class BaseGrid:
     ):
         # reset the  distToClosestSurf and the freePoints
         # boundingBox should be the same otherwise why keeping the grid
-        # self.gridPtId = numpy.zeros(self.gridVolume,'i')
-        # self.distToClosestSurf = numpy.ones(self.gridVolume)*self.diag#(self.distToClosestSurf)
         self.log.info("reset Grid distance to closest surface and freePoints")
         self.distToClosestSurf = (
             numpy.array(self.distToClosestSurf[:]) * 0.0
@@ -255,9 +247,9 @@ class BaseGrid:
     def getDiagonal(self, boundingBox=None):
         if boundingBox is None:
             boundingBox = self.boundingBox
-        self.diag = numpy.sqrt(
-            (numpy.array(boundingBox[0]) - numpy.array(boundingBox[1])) ** 2
-        ).sum()
+        self.diag = numpy.linalg.norm(
+            (numpy.array(boundingBox[0]) - numpy.array(boundingBox[1]))
+        )
         return self.diag
 
     def create3DPointLookup_loop(self, boundingBox=None):
@@ -288,7 +280,7 @@ class BaseGrid:
                     pointArrayRaw[i] = (x, y, z)
                     self.ijkPtIndice[i] = (xi, yi, zi)
                     i += 1
-        self.log.info("grid spacing %d", space)
+        self.log.info(f"grid spacing {space}")
         self.masterGridPositions = pointArrayRaw
 
     def create3DPointLookup(self, boundingBox=None):
@@ -398,30 +390,6 @@ class BaseGrid:
         self.ijkPtIndice = numpy.ndindex(nx, ny, nz)
         self.masterGridPositions = numpy.vstack(xyz).reshape(3, -1).T
 
-    #        self.masterGridPositions = numpy.vstack(numpy.meshgrid(x,y,z,copy=False)).reshape(3,-1).T
-
-    def getPointCompartmentId(self, point, ray=1):
-        # check if point inside on of the compartments
-        # surface point ?
-        n_comp = len(self.histoVol.compartments)
-        if n_comp:
-            for i in range(n_comp):
-                inside = self.checkPointInside_rapid(
-                    self.histoVol.compartments[i],
-                    point,
-                    self.histoVol.grid.diag,
-                    ray=ray,
-                )
-                if inside:
-                    return -(i + 1)
-                    # comp=comp-1
-            # the point is not inside , is it on the surface ? ie distance to surface < X?
-            for i in range(n_comp):
-                distance, nb = self.histoVol.compartments[i].OGsrfPtsBht.query(point)
-                if distance < 10.0:
-                    return i + 1
-        return 0
-
     def getClosestGridPoint(self, pt3d):
         if self.tree is None:
             self.tree = spatial.cKDTree(self.masterGridPositions, leafsize=10)
@@ -433,7 +401,7 @@ class BaseGrid:
     ):
         free_indices = self.freePoints[: self.nbFreePoints]
         arr = numpy.array(self.masterGridPositions[free_indices])
-        indices = numpy.nonzero(numpy.equal(self.gridPtId[free_indices], compId))
+        indices = numpy.nonzero(numpy.equal(self.compartment_ids[free_indices], compId))
         distances = self.distToClosestSurf[free_indices]
         if not len(indices):
             return None
@@ -465,7 +433,7 @@ class BaseGrid:
             if compId is not None:
                 arr = numpy.array(self.masterGridPositions[free_indices])
                 indices = numpy.nonzero(
-                    numpy.equal(self.gridPtId[free_indices], compId)
+                    numpy.equal(self.compartment_ids[free_indices], compId)
                 )
                 self.tree_free = spatial.cKDTree(arr[indices], leafsize=10)
                 arr = arr[indices]
@@ -784,12 +752,12 @@ class BaseGrid:
         return ptIndices
 
     def test_points_in_bb(self, bb, pt):
-        # given a bounding box, does the point is contains in it
+        # given a bounding box bb, is point pt inside it
         origin = numpy.array(bb[0])
-        E = numpy.array(bb[1])
-        P = numpy.array(pt)  # *jitter
-        test1 = P < origin
-        test2 = P > E
+        corner = numpy.array(bb[1])
+        point_to_check = numpy.array(pt)  # *jitter
+        test1 = point_to_check < origin
+        test2 = point_to_check > corner
         inside = False
         if True in test1 or True in test2:
             # outside
@@ -854,7 +822,7 @@ class BaseGrid:
     def set_surfPtsBht(self, verts):
         self.surfPtsBht = None
         if verts is not None and len(verts):
-            self.surfPtsBht = bhtreelib.BHtree(verts, None, 10)
+            self.surfPtsBht = spatial.cKDTree(verts, leafsize=10)
         self.nbSurfacePoints = len(verts)
 
     def set_surfPtscht(self, verts):
@@ -886,146 +854,7 @@ class BaseGrid:
             totalVolume = V * unitVol
         return totalVolume
 
-    def create_rapid_model(self):
-        self.rapid_model = RAPIDlib.RAPID_model()
-        # need triangle and vertices
-        self.rapid_model.addTriangles(
-            numpy.array(self.vertices, "f"), numpy.array(self.faces, "i")
-        )
-
-    def get_rapid_model(self):
-        if self.rapid_model is None:
-            self.create_rapid_model()
-        return self.rapid_model
-
-    def one_rapid_ray(self, pt1, pt2, diag):
-        # return number of triangle /triangle contact
-        helper = autopack.helper
-        rm = self.get_rapid_model()
-        v1 = numpy.array(pt1)
-        direction = helper.unit_vector(pt2 - pt1) * diag
-        v2 = v1 + direction
-        if sum(v1) == 0.0:
-            v3 = v2 + numpy.array([0.0, 1.0, 0.0])
-        else:
-            v3 = v2 + helper.unit_vector(numpy.cross(v1, v2))
-        f = [0, 1, 2]
-        ray_model = RAPIDlib.RAPID_model()
-        ray_model.addTriangles(
-            numpy.array([v1, v2, v3], "f"),
-            numpy.array(
-                [f],
-                "i",
-            ),
-        )
-        RAPIDlib.RAPID_Collide_scaled(
-            numpy.identity(3),
-            numpy.array([0.0, 0.0, 0.0], "f"),
-            1.0,
-            rm,
-            numpy.identity(3),
-            numpy.array([0.0, 0.0, 0.0], "f"),
-            1.0,
-            ray_model,
-            RAPIDlib.cvar.RAPID_ALL_CONTACTS,
-        )
-        # could display it ?
-        return RAPIDlib.cvar.RAPID_num_contacts
-
-    def checkPointInside_rapid(self, point, diag, ray=1):
-        # we want to be sure to cover the organelle
-        if diag < self.diag:
-            diag = self.diag
-        inside = False
-        v1 = numpy.array(point)
-        self.getCenter()
-        count1 = self.one_rapid_ray(v1, v1 + numpy.array([0.0, 0.0, 1.1]), diag)
-        r = (count1 % 2) == 1  # inside ?
-        # we need 2 out of 3 ?
-        if ray == 3:
-            count2 = self.one_rapid_ray(v1, numpy.array(self.center), diag)
-            if (count2 % 2) == 1 and r:
-                return True
-            count3 = self.one_rapid_ray(v1, v1 + numpy.array([0.0, 1.1, 0.0]), diag)
-            if (count3 % 2) == 1 and r:
-                return True
-            return False
-        if r:  # odd inside
-            inside = True
-        return inside
-
-    def getSurfaceInnerPoints_jordan(self, vertices, faces, ray=1):
-        """
-        Only computes the inner point. No grid.
-        This is independent from the packing. Help build ingredient sphere tree and representation.
-        - Uses BHTree to compute surface points
-        - Uses Jordan raycasting to determine inside/outside (defaults to 1 iteration, can use 3 iterations)
-        """
-        self.vertices = vertices
-        self.faces = faces
-        self.rapid_model = None
-        self.center = None
-        xl, yl, zl = self.boundingBox[0]  # lower left bounding box corner
-        xr, yr, zr = self.boundingBox[1]  # upper right bounding box corner
-        # distToClosestSurf is set to self.diag initially
-        distances = self.distToClosestSurf
-        diag = self.diag
-
-        # Get surface points using bhtree (stored in bht and OGsrfPtsBht)
-        # otherwise, regard vertices as surface points.
-
-        self.ogsurfacePoints = vertices[
-            :
-        ]  # Makes a copy of the vertices and vnormals lists
-        surfacePoints = srfPts = self.ogsurfacePoints
-
-        # self.OGsrfPtsBht = bht =  bhtreelib.BHtree(tuple(srfPts), None, 10)
-        self.OGsrfPtsBht = bht = spatial.cKDTree(tuple(srfPts), leafsize=10)
-
-        insidePoints = []
-        grdPos = self.masterGridPositions
-        closest = bht.query(tuple(grdPos))
-
-        self.closestId = closest[1]
-        new_distances = closest[0]
-        mask = distances[: len(grdPos)] > new_distances
-        n_indices = numpy.nonzero(mask)
-        distances[n_indices] = new_distances[n_indices]
-        self.grid_distances = distances
-        # returnNullIfFail = 0
-        for ptInd in range(len(grdPos)):  # len(grdPos)):
-            inside = False  # inside defaults to False (meaning outside), unless evidence is found otherwise.
-            # t2=time()
-            coord = [
-                grdPos.item((ptInd, 0)),
-                grdPos.item((ptInd, 1)),
-                grdPos.item((ptInd, 2)),
-            ]  # grdPos[ptInd]
-            insideBB = self.checkPointInside(
-                coord, dist=new_distances.item(ptInd)
-            )  # inside the BB of the surface ?
-            if insideBB:
-                r = self.checkPointInside_rapid(coord, diag, ray=ray)
-                if r:  # odd inside
-                    insidePoints.append(
-                        grdPos[ptInd]
-                    )  # Append the index to the list of inside indices.
-            p = (ptInd / float(len(grdPos))) * 100.0
-            if (ptInd % 100) == 0:
-                self.log.info(
-                    "points from jordan",
-                    int(p),
-                    str(ptInd)
-                    + "/"
-                    + str(len(grdPos))
-                    + " inside "
-                    + str(inside)
-                    + " "
-                    + str(insideBB),
-                )
-        return insidePoints, surfacePoints
-
-        # ==============================================================================
+    # ==============================================================================
 
     # TO DO File IO
     # ==============================================================================
@@ -1040,7 +869,7 @@ class BaseGrid:
 class HaltonGrid(BaseGrid):
     def __init__(self, boundingBox=([0, 0, 0], [0.1, 0.1, 0.1]), space=1, setup=False):
         BaseGrid.__init__(
-            self, boundingBox=boundingBox, space=space, setup=setup, lookup=1
+            self, boundingBox=boundingBox, spacing=space, setup=setup, lookup=1
         )
         self.haltonseq = cHaltonSequence3()
         self.tree = None
