@@ -6,10 +6,11 @@ Created on Sun Jan 27 09:04:10 2013
 """
 import os
 import pickle
+import webbrowser
 
 import numpy
-from xml.dom.minidom import getDOMImplementation
 import json
+from json import JSONEncoder
 from json import encoder
 from collections import OrderedDict
 
@@ -17,7 +18,7 @@ from numpy.core.arrayprint import printoptions
 
 import cellpack.autopack as autopack
 import cellpack.autopack.transformation as tr
-from .ingredient.Ingredient import KWDS
+from .ingredient.Ingredient import Ingredient
 from cellpack.autopack.Serializable import (
     sCompartment,
     sIngredientGroup,
@@ -25,19 +26,21 @@ from cellpack.autopack.Serializable import (
     sIngredientFiber,
 )
 from cellpack.autopack.Recipe import Recipe
-from cellpack.autopack.Compartment import Compartment
 from .ingredient import (
     ActinIngredient,
-    SingleSphereIngr,
-    MultiSphereIngr,
-    SingleCubeIngr,
-    MultiCylindersIngr,
     GrowIngredient,
 )
 
 encoder.FLOAT_REPR = lambda o: format(o, ".8g")
 
 
+class NumpyArrayEncoder(JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, numpy.ndarray):
+            return obj.tolist()
+        return JSONEncoder.default(self, obj)
+
+
 def getValueToXMLNode(vtype, node, attrname):
     value = node.getAttribute(attrname)
     value = str(value)
@@ -217,11 +220,6 @@ class IOingredientTool(object):
                 json.dump(
                     ingdic, fp, indent=1, separators=(",", ":")
                 )  # ,indent=4, separators=(',', ': ')
-        elif ingr_format == "xml":
-            ingrnode, xmldoc = self.ingrXmlNode(ingr)
-            f = open(filename + ".xml", "w")
-            xmldoc.writexml(f, indent="\t", addindent="", newl="\n")
-            f.close()
         elif ingr_format == "python":
             ingrnode = self.ingrPythonNode(ingr)
             f = open(filename + ".py", "w")
@@ -233,77 +231,12 @@ class IOingredientTool(object):
                 json.dump(
                     ingdic, fp, indent=4, separators=(",", ": ")
                 )  # ,indent=4, separators=(',', ': ')
-            ingrnode, xmldoc = self.ingrXmlNode(ingr)
-            f = open(filename + ".xml", "w")
-            xmldoc.writexml(f, indent="\t", addindent="", newl="\n")
-            f.close()
             ingrnode = self.ingrPythonNode(ingr)
             f = open(filename + ".py", "w")
             f.write(ingrnode)
             f.close()
 
-    def makeIngredientFromXml(self, inode=None, filename=None, recipe="Generic"):
-        if filename is None and inode is not None:
-            f = str(inode.getAttribute("include"))
-            if f != "":
-                filename = str(f)
-        if filename is not None:
-            # filter the filename or pass the custom-path?
-            filename = autopack.retrieveFile(
-                filename,
-                # destination = recipe+os.sep+"recipe"+os.sep+"ingredients"+os.sep,
-                cache="recipes",
-            )
-            from xml.dom.minidom import parse
-
-            print("parsing an ingredient xml", filename)
-            xmlingr = parse(filename)  # parse an XML file by name
-            ingrnode = xmlingr.documentElement
-        elif inode is not None:
-            ingrnode = inode
-        else:
-            print("filename is None")
-            return None
-        kw = self.parseIngrXmlNode(ingrnode)
-        # check for overwritten parameter
-        overwrite_node = inode.getElementsByTagName("overwrite")
-        if len(overwrite_node):
-            kwo = self.parseIngrXmlNode(overwrite_node[0])
-            kw.update(kwo)
-        name = str(ingrnode.getAttribute("name"))
-        kw.update({"name": name})
-        ingre = self.makeIngredient(**kw)
-        return ingre
-
-    def parseIngrXmlNode(self, ingrnode):
-        kw = {}
-        for k in KWDS:
-            v = getValueToXMLNode(KWDS[k]["type"], ingrnode, k)
-            if v is not None:
-                kw[k] = v
-        return kw
-
-    def ingrXmlNode(self, ingr, xmldoc=None):
-        rxmldoc = False
-        if xmldoc is None:
-            rxmldoc = True
-            impl = getDOMImplementation()
-            # what about afviewer
-            xmldoc = impl.createDocument(None, "ingredient", None)
-            ingrnode = xmldoc.documentElement
-            ingrnode.setAttribute("name", str(ingr.name))
-        else:
-            ingrnode = xmldoc.createElement("ingredient")
-            ingrnode.setAttribute("name", str(ingr.name))
-        for k in ingr.KWDS:
-            v = getattr(ingr, k)
-            setValueToXMLNode(v, ingrnode, k)
-        if rxmldoc:
-            return ingrnode, xmldoc
-        else:
-            return ingrnode
-
-    def makeIngredientFromJson(self, inode=None, filename=None, recipe="Generic"):
+    def makeIngredientFromJson(self, env, inode=None, filename=None, recipe="Generic"):
         overwrite_dic = {}
         ingr_dic = {}
         if filename is None and inode is not None:
@@ -328,7 +261,7 @@ class IOingredientTool(object):
         # check for overwritten parameter
         if len(overwrite_dic):
             kw.update(overwrite_dic)
-        ingre = self.makeIngredient(**kw)
+        ingre = self.makeIngredient(env, **kw)
         return ingre
 
     def ingrJsonNode(self, ingr, result=False, kwds=None, transpose=False):
@@ -410,32 +343,26 @@ class IOingredientTool(object):
         inrStr += recipe + ".addIngredient(" + ingr.name + ")\n"
         return inrStr
 
-    def makeIngredient(self, **kw):
+    @staticmethod
+    def clean_arguments(arguments_to_include, **arguments):
+        new_arguments = {}
+        for index, name in enumerate(arguments):
+            if name in arguments_to_include:
+                new_arguments[name] = arguments[name]
+        return new_arguments
 
+    def makeIngredient(self, env, **kw):
         ingr = None
-        if kw["Type"] == "SingleSphere":
-            kw["position"] = kw["positions"][0][0]
-            kw["radius"] = kw["radii"][0][0]
-            del kw["positions"]
-            del kw["radii"]
-            ingr = SingleSphereIngr(**kw)
-        elif kw["Type"] == "MultiSphere":
-            ingr = MultiSphereIngr(**kw)
-        elif kw["Type"] == "MultiCylinder":
-            ingr = MultiCylindersIngr(**kw)
-        elif kw["Type"] == "SingleCube":
-            kw["positions"] = [[[0, 0, 0], [0, 0, 0], [0, 0, 0]]]
-            kw["positions2"] = None
-            ingr = SingleCubeIngr(**kw)
-        elif kw["Type"] == "Grow":
-            ingr = GrowIngredient(**kw)
-        elif kw["Type"] == "Actine":
-            ingr = ActinIngredient(**kw)
-        if "gradient" in kw and kw["gradient"] != "" and kw["gradient"] != "None":
-            ingr.gradient = kw["gradient"]
-        if "results" in kw:
-            ingr.results = kw["results"]
-            # flag as previously loaded ?
+        ingredient_type = kw["Type"]
+        if (
+            ingredient_type == "Grow"
+            or ingredient_type == "Actine"
+            or ingredient_type == "MultiCylinder"
+        ):
+            arguments = IOingredientTool.clean_arguments(GrowIngredient.ARGUMENTS, **kw)
+        else:
+            arguments = IOingredientTool.clean_arguments(Ingredient.ARGUMENTS, **kw)
+        ingr = env.create_ingredient(**arguments)
         return ingr
 
     def set_recipe_ingredient(self, xmlnode, recipe):
@@ -491,15 +418,6 @@ def addCompartments(env, compdic, i, io_ingr):
             rep_file = ""
             if "rep_file" in comp_dic:
                 rep_file = str(comp_dic["rep_file"])
-            # print(
-            #    "rep ?",
-            #    name,
-            #    geom,
-            #    rep,
-            #    rep_file,
-            #    (rep != "None" and len(rep) != 0 and rep != "" and rep == ""),
-            # )
-            #                print (len(rep),rep == '',rep=="",rep != "None",rep != "None" or len(rep) != 0)
             if rep != "None" and len(rep) != 0 and rep != "" and rep != "":
                 rname = rep_file.split("/")[-1]
                 fileName, fileExtension = os.path.splitext(rname)
@@ -512,22 +430,15 @@ def addCompartments(env, compdic, i, io_ingr):
             else:
                 rep = None
                 rep_file = None
-                print("NONENE")
             print("add compartment ", name, geom, rep, rep_file)
-            o = Compartment(
-                name,
-                None,
-                None,
-                None,
-                filename=geom,
-                gname=str(comp_dic["name"]),
-                object_name=rep,
-                object_filename=rep_file,
+            compartment = env.create_compartment(
+                name, geom, str(comp_dic["name"]), rep, rep_file
             )
-            print("added compartment ", name)
             # need to transform the v,f,n to the new rotation and position
-            o.transformMesh(pos, rot)
-            env.addCompartment(o)
+            # NOTE: we could initialize compartments with pos and rot instead
+            # of transforming it every time we make a new one
+            compartment.transformMesh(pos, rot)
+            env.addCompartment(compartment)
             if "surface" in comp_dic:
                 snode = comp_dic["surface"]
                 ingrs_dic = snode["ingredients"]
@@ -538,11 +449,11 @@ def addCompartments(env, compdic, i, io_ingr):
                         # either xref or defined
                         ing_dic = ingrs_dic[ing_name]
                         ingr = io_ingr.makeIngredientFromJson(
-                            inode=ing_dic, recipe=env.name
+                            env=env, inode=ing_dic, recipe=env.name
                         )
                         rSurf.addIngredient(ingr)
                         # setup recipe
-                    o.setSurfaceRecipe(rSurf)
+                    compartment.setSurfaceRecipe(rSurf)
             if "interior" in comp_dic:
                 snode = comp_dic["interior"]
                 ingrs_dic = snode["ingredients"]
@@ -553,186 +464,25 @@ def addCompartments(env, compdic, i, io_ingr):
                         # either xref or defined
                         ing_dic = ingrs_dic[ing_name]
                         ingr = io_ingr.makeIngredientFromJson(
-                            inode=ing_dic, recipe=env.name
+                            env=env, inode=ing_dic, recipe=env.name
                         )
                         rMatrix.addIngredient(ingr)
                         # setup recipe
-                    o.setInnerRecipe(rMatrix)
-
-                    # put here the export/import ?
+                    compartment.setInnerRecipe(rMatrix)
 
 
-def save_asJson(env, setupfile, useXref=True, indent=True):
-    """
-    Save the current environment setup as an json file.
-    env is the environment / recipe to be exported.
-    """
-    io_ingr = IOingredientTool(env=env)
-    env.setupfile = setupfile  # +".json"provide the server?
-    # the output path for this recipes files
-    if env.setupfile.find("http") != -1 or env.setupfile.find("ftp") != -1:
-        pathout = os.path.dirname(os.path.abspath(autopack.retrieveFile(env.setupfile)))
-    else:
-        pathout = os.path.dirname(os.path.abspath(env.setupfile))
-    if env.version is None:
-        env.version = "1.0"
-    env.jsondic = OrderedDict()
-    env.jsondic["recipe"] = OrderedDict()
-    env.jsondic["recipe"]["name"] = env.name
-    env.jsondic["recipe"]["version"] = env.version
-    if env.custom_paths:
-        # this was the used path at loading time
-        env.jsondic["recipe"]["paths"] = env.custom_paths
-    env.jsondic["options"] = OrderedDict()
-    for k in env.OPTIONS:
-        v = getattr(env, str(k))
-        if k == "gradients":
-            if type(env.gradients) is dict:
-                v = list(env.gradients.keys())
-        #            elif k == "runTimeDisplay"
-        env.jsondic["options"].update(setValueToJsonNode(v, str(k)))
-    # add the boundin box
-    env.jsondic["options"].update(setValueToJsonNode(env.boundingBox, "boundingBox"))
-
-    # grid path information
-    if env.grid is not None:
-        if env.grid.filename is not None or env.grid.result_filename is not None:
-            env.jsondic["grid"] = OrderedDict()
-            env.jsondic["grid"]["grid_storage"] = str(env.grid.filename)
-            env.jsondic["grid"]["grid_result"] = str(env.grid.result_filename)
-
-    # gradient information
-    if len(env.gradients):
-        env.jsondic["gradients"] = OrderedDict()
-        for gname in env.gradients:
-            g = env.gradients[gname]
-            env.jsondic["gradients"][str(g.name)] = OrderedDict()
-            for k in g.OPTIONS:
-                v = getattr(g, str(k))
-                env.jsondic["gradients"][str(g.name)].update(
-                    setValueToJsonNode(v, str(k))
-                )
-
-    r = env.exteriorRecipe
-    if r:
-        env.jsondic["cytoplasme"] = OrderedDict()
-        env.jsondic["cytoplasme"]["ingredients"] = OrderedDict()
-        for ingr in r.ingredients:
-            if useXref:
-                # write the json file for this ingredient
-                io_ingr.write(ingr, pathout + os.sep + ingr.o_name, ingr_format="json")
-                # use reference file : str(pathout+os.sep+ingr.o_name+".json")
-                ing_filename = (
-                    ingr.o_name + ".json"
-                )  # autopack.revertOnePath(pathout+os.sep+ingr.o_name+".json")
-                env.jsondic["cytoplasme"]["ingredients"][ingr.o_name] = OrderedDict()
-                env.jsondic["cytoplasme"]["ingredients"][ingr.o_name][
-                    "name"
-                ] = ingr.o_name
-                env.jsondic["cytoplasme"]["ingredients"][ingr.o_name][
-                    "include"
-                ] = ing_filename
-            else:
-                env.jsondic["cytoplasme"]["ingredients"][
-                    ingr.o_name
-                ] = io_ingr.ingrJsonNode(
-                    ingr
-                )  # {"name":ingr.o_name}
-                env.jsondic["cytoplasme"]["ingredients"][ingr.o_name][
-                    "name"
-                ] = ingr.o_name
-    if len(env.compartments):
-        env.jsondic["compartments"] = OrderedDict()
-    for o in env.compartments:
-        env.jsondic["compartments"][str(o.name)] = OrderedDict()
-        env.jsondic["compartments"][str(o.name)]["geom"] = str(
-            o.filename
-        )  # should point to the used filename
-        env.jsondic["compartments"][str(o.name)]["name"] = str(o.ref_obj)
-        if o.representation is not None:
-            fileName, fileExtension = os.path.splitext(o.representation_file)
-            env.jsondic["compartments"][str(o.name)]["rep"] = str(
-                o.representation
-            )  # None
-            env.jsondic["compartments"][str(o.name)]["rep_file"] = str(fileName)
-        #            else :
-        #                fileName = None
-        rs = o.surfaceRecipe
-        if rs:
-            env.jsondic["compartments"][str(o.name)]["surface"] = OrderedDict()
-            env.jsondic["compartments"][str(o.name)]["surface"][
-                "ingredients"
-            ] = OrderedDict()
-            for ingr in rs.ingredients:
-                if useXref:
-                    # write the json file for this ingredient
-                    io_ingr.write(
-                        ingr, pathout + os.sep + ingr.o_name, ingr_format="json"
-                    )
-                    # use reference file
-                    env.jsondic["compartments"][str(o.name)]["surface"]["ingredients"][
-                        ingr.o_name
-                    ] = OrderedDict()
-                    env.jsondic["compartments"][str(o.name)]["surface"]["ingredients"][
-                        ingr.o_name
-                    ]["name"] = ingr.o_name
-                    env.jsondic["compartments"][str(o.name)]["surface"]["ingredients"][
-                        ingr.o_name
-                    ]["include"] = str(ingr.o_name + ".json")
-                else:
-                    env.jsondic["compartments"][str(o.name)]["surface"]["ingredients"][
-                        ingr.o_name
-                    ] = io_ingr.ingrJsonNode(
-                        ingr
-                    )  # {"name":ingr.o_name}
-                    env.jsondic["compartments"][str(o.name)]["surface"]["ingredients"][
-                        ingr.o_name
-                    ]["name"] = ingr.o_name
-        ri = o.innerRecipe
-        if ri:
-            env.jsondic["compartments"][str(o.name)]["interior"] = OrderedDict()
-            env.jsondic["compartments"][str(o.name)]["interior"][
-                "ingredients"
-            ] = OrderedDict()
-            for ingr in ri.ingredients:
-                if useXref:
-                    # write the json file for this ingredient
-                    io_ingr.write(
-                        ingr, pathout + os.sep + ingr.o_name, ingr_format="json"
-                    )
-                    # use reference file
-                    env.jsondic["compartments"][str(o.name)]["interior"]["ingredients"][
-                        ingr.o_name
-                    ] = OrderedDict()
-                    env.jsondic["compartments"][str(o.name)]["interior"]["ingredients"][
-                        ingr.o_name
-                    ]["name"] = ingr.o_name
-                    env.jsondic["compartments"][str(o.name)]["interior"]["ingredients"][
-                        ingr.o_name
-                    ]["include"] = str(ingr.o_name + ".json")
-                else:
-                    env.jsondic["compartments"][str(o.name)]["interior"]["ingredients"][
-                        ingr.o_name
-                    ] = io_ingr.ingrJsonNode(
-                        ingr
-                    )  # {"name":ingr.o_name}
-                    env.jsondic["compartments"][str(o.name)]["interior"]["ingredients"][
-                        ingr.o_name
-                    ]["name"] = ingr.o_name
-
-    def default(o):
-        raise TypeError(repr(o) + " is not JSON serializable ", o, type(o))
-
-    with open(setupfile, "w") as fp:  # doesnt work with symbol link ?
-        if indent:
-            json.dump(
-                env.jsondic, fp, indent=1, separators=(",", ":"), default=default
-            )  # ,indent=4, separators=(',', ': ')
-        else:
-            json.dump(
-                env.jsondic, fp, separators=(",", ":"), default=default
-            )  # ,indent=4, separators=(',', ': ')
-    print("recipe saved to ", setupfile)
+def save_as_simularium(env, setupfile, all_ingr_as_array, compartments):
+    autopack.helper.clear()
+    grid_positions = env.grid.masterGridPositions if env.show_grid_spheres else None
+    compartment_ids = env.grid.compartment_ids if env.show_grid_spheres else None
+    autopack.helper.init_scene_with_objects(
+        all_ingr_as_array, grid_positions, compartment_ids, env.show_sphere_trees
+    )
+    if compartments is not None:
+        for compartment in compartments:
+            autopack.helper.add_compartment_to_scene(compartment)
+    autopack.helper.writeToFile(None, f"{setupfile}_results", env.boundingBox)
+    webbrowser.open("https://simularium.allencell.org/viewer")
 
 
 def save_Mixed_asJson(
@@ -905,139 +655,18 @@ def save_Mixed_asJson(
                         ingr.o_name
                     ]["name"] = ingr.o_name
     with open(setupfile, "w") as fp:  # doesnt work with symbol link ?
+
         if indent:
             json.dump(
-                env.jsondic, fp, indent=1, separators=(",", ":")
+                env.jsondic, fp, indent=1, separators=(",", ":"), cls=NumpyArrayEncoder
             )  # ,indent=4, separators=(',', ': ')
         else:
             json.dump(
-                env.jsondic, fp, separators=(",", ":")
+                env.jsondic, fp, separators=(",", ":"), cls=NumpyArrayEncoder
             )  # ,indent=4, separators=(',', ': ')
     printoptions("Mixed recipe saved to ", setupfile)
 
 
-def save_asXML(env, setupfile, useXref=True):
-    """
-    Save the current environment setup as an xml file.
-    env is the environment / recipe to be exported.
-    """
-    io_ingr = IOingredientTool(env=env)
-    #        env.setupfile = setupfile+".xml"
-    pathout = os.path.dirname(os.path.abspath(env.setupfile))
-    # export all information as xml
-    from xml.dom.minidom import getDOMImplementation
-
-    impl = getDOMImplementation()
-    # what about afviewer
-    env.xmldoc = impl.createDocument(None, "autopackSetup", None)
-    root = env.xmldoc.documentElement
-    root.setAttribute("name", str(env.name))
-    if env.custom_paths:
-        setValueToXMLNode(env.custom_paths, root, "paths")
-    options = env.xmldoc.createElement("options")
-    for k in env.OPTIONS:
-        v = getattr(env, k)
-        if k == "gradients":
-            v = list(env.gradients.keys())
-        #            elif k == "runTimeDisplay"
-        setValueToXMLNode(v, options, k)
-    # add the boundin box
-    setValueToXMLNode(env.boundingBox, options, "boundingBox")
-    setValueToXMLNode(env.version, options, "version")  # version?
-    root.appendChild(options)
-
-    if len(env.gradients):
-        gradientsnode = env.xmldoc.createElement("gradients")
-        root.appendChild(gradientsnode)
-        for gname in env.gradients:
-            g = env.gradients[gname]
-            grnode = env.xmldoc.createElement("gradient")
-            gradientsnode.appendChild(grnode)
-            grnode.setAttribute("name", str(g.name))
-            for k in g.OPTIONS:
-                v = getattr(g, k)
-                setValueToXMLNode(v, grnode, k)
-
-                # grid path information
-    if env.grid.filename is not None or env.grid.result_filename is not None:
-        gridnode = env.xmldoc.createElement("grid")
-        root.appendChild(gridnode)
-        gridnode.setAttribute("grid_storage", str(env.grid.filename))
-        gridnode.setAttribute("grid_result", str(env.grid.result_filename))
-
-    r = env.exteriorRecipe
-    if r:
-        rnode = env.xmldoc.createElement("cytoplasme")
-        root.appendChild(rnode)
-        for ingr in r.ingredients:
-            if useXref:
-                io_ingr.write(ingr, pathout + os.sep + ingr.name, ingr_format="xml")
-                ingrnode = env.xmldoc.createElement("ingredient")
-                rnode.appendChild(ingrnode)
-                ingrnode.setAttribute(
-                    "include", str(pathout + os.sep + ingr.name + ".xml")
-                )
-            else:
-                ingrnode = env.xmldoc.createElement("ingredient")
-                rnode.appendChild(ingrnode)
-                ingrnode.setAttribute("name", str(ingr.name))
-                for k in ingr.KWDS:
-                    v = getattr(ingr, k)
-                    setValueToXMLNode(v, ingrnode, k)
-    for o in env.compartments:
-        onode = env.xmldoc.createElement("compartment")
-        root.appendChild(onode)
-        onode.setAttribute("name", str(o.name))
-        onode.setAttribute("geom", str(o.filename))  # should point to the used filename
-        onode.setAttribute("rep", str(o.representation))  # None
-        if o.representation is not None:
-            fileName, fileExtension = os.path.splitext(o.representation_file)
-        else:
-            fileName = None
-        onode.setAttribute("rep_file", str(fileName))  # None
-        rs = o.surfaceRecipe
-        if rs:
-            onodesurface = env.xmldoc.createElement("surface")
-            onode.appendChild(onodesurface)
-            for ingr in rs.ingredients:
-                if useXref:
-                    io_ingr.write(ingr, pathout + os.sep + ingr.name, ingr_format="xml")
-                    ingrnode = env.xmldoc.createElement("ingredient")
-                    onodesurface.appendChild(ingrnode)
-                    ingrnode.setAttribute(
-                        "include", str(pathout + os.sep + ingr.name + ".xml")
-                    )
-                else:
-                    ingrnode = env.xmldoc.createElement("ingredient")
-                    onodesurface.appendChild(ingrnode)
-                    ingrnode.setAttribute("name", str(ingr.name))
-                    for k in ingr.KWDS:
-                        v = getattr(ingr, k)
-                        setValueToXMLNode(v, ingrnode, k)
-        ri = o.innerRecipe
-        if ri:
-            onodeinterior = env.xmldoc.createElement("interior")
-            onode.appendChild(onodeinterior)
-            for ingr in ri.ingredients:
-                if useXref:
-                    io_ingr.write(ingr, pathout + os.sep + ingr.name, ingr_format="xml")
-                    ingrnode = env.xmldoc.createElement("ingredient")
-                    onodeinterior.appendChild(ingrnode)
-                    ingrnode.setAttribute(
-                        "include", str(pathout + os.sep + ingr.name + ".xml")
-                    )
-                else:
-                    ingrnode = env.xmldoc.createElement("ingredient")
-                    onodeinterior.appendChild(ingrnode)
-                    ingrnode.setAttribute("name", str(ingr.name))
-                    for k in ingr.KWDS:
-                        v = getattr(ingr, k)
-                        setValueToXMLNode(v, ingrnode, k)
-    f = open(setupfile, "w")
-    env.xmldoc.writexml(f, indent="\t", addindent="", newl="\n")
-    f.close()
-
-
 def save_asPython(env, setupfile, useXref=True):
     """
     Save the current environment setup as a python script file.
@@ -1762,167 +1391,6 @@ def getAllPosRot(env, transpose, use_quaternion, lefthand=False):
     return all_pos, all_rot
 
 
-def load_XML(env, setupfile):
-    """
-    Setup the environment according the given xml file.
-    """
-    env.setupfile = setupfile
-    io_ingr = IOingredientTool(env=env)
-    from xml.dom.minidom import parse
-
-    env.xmldoc = parse(setupfile)  # parse an XML file by name
-    root = env.xmldoc.documentElement
-    env.name = str(root.getAttribute("name"))
-    env.custom_paths = getValueToXMLNode("g", root, "paths")
-    env.current_path = os.path.dirname(os.path.abspath(env.setupfile))
-    if env.custom_paths:
-        autopack.updateReplacePath(env.custom_paths)
-    autopack.current_recipe_path = env.current_path
-    options = root.getElementsByTagName("options")
-    if len(options):
-        options = options[0]
-        for k in env.OPTIONS:
-            if k == "gradients":
-                continue
-            v = getValueToXMLNode(env.OPTIONS[k]["type"], options, k)
-            if v is not None:
-                setattr(env, k, v)
-        boudning_box = getValueToXMLNode("vector", options, "boundingBox")
-        env.boundingBox = boudning_box
-        version = getValueToXMLNode("string", options, "version")
-        env.version = version
-
-    gradientsnode = root.getElementsByTagName("gradients")
-    if len(gradientsnode):
-        gradientnode = gradientsnode[0]
-        grnodes = gradientnode.getElementsByTagName("gradient")
-        for grnode in grnodes:
-            name = str(grnode.getAttribute("name"))
-            mode = str(grnode.getAttribute("mode"))
-            weight_mode = str(grnode.getAttribute("weight_mode"))
-            pick_mode = str(grnode.getAttribute("pick_mode"))
-            direction = str(grnode.getAttribute("direction"))  # vector
-            description = str(grnode.getAttribute("description"))
-            radius = float(str(grnode.getAttribute("radius")))
-            env.setGradient(
-                name=name,
-                mode=mode,
-                direction=eval(direction),
-                weight_mode=weight_mode,
-                description=description,
-                pick_mode=pick_mode,
-                radius=radius,
-            )
-
-    gridnode = root.getElementsByTagName("grid")
-    if len(gridnode):
-        gridn = gridnode[0]
-        env.grid_filename = str(gridn.getAttribute("grid_storage"))
-        env.grid_result_filename = str(gridn.getAttribute("grid_result"))
-
-    rnode = root.getElementsByTagName("cytoplasme")
-    if len(rnode):
-        rCyto = Recipe()
-        rnode = rnode[0]
-        # check for include list of ingredients
-        ingredients_xmlfile = str(rnode.getAttribute("include"))
-        if ingredients_xmlfile:  # open the file and parse the ingredient:
-            # check if multiple include filename, aumngo',' in the path
-            liste_xmlfile = ingredients_xmlfile.split(",")
-            for xmlf in liste_xmlfile:
-                xmlfile = autopack.retrieveFile(
-                    xmlf,
-                    # destination = self.name+os.sep+"recipe"+os.sep,
-                    cache="recipes",
-                )
-                if xmlfile:
-                    xmlinclude = parse(xmlfile).documentElement
-                    io_ingr.set_recipe_ingredient(xmlinclude, rCyto)
-
-        io_ingr.set_recipe_ingredient(rnode, rCyto)
-        # setup recipe
-        env.setExteriorRecipe(rCyto)
-
-    onodes = root.getElementsByTagName("compartment")  # Change to Compartment
-    if not len(onodes):
-        # backward compatibility
-        onodes = root.getElementsByTagName("organelle")  # Change to Compartment
-
-    for onode in onodes:
-        name = str(onode.getAttribute("name"))
-        geom = str(onode.getAttribute("geom"))
-        rep = str(onode.getAttribute("rep"))
-        rep_file = str(onode.getAttribute("rep_file"))
-        print("xml parsing ", name, geom, rep, rep_file)
-        if rep != "None" and len(rep) != 0:
-            rname = rep_file.split("/")[-1]
-            fileName, fileExtension = os.path.splitext(rname)
-            if fileExtension == "":
-                fileExtension = autopack.helper.hext
-                if fileExtension == "":
-                    rep_file = rep_file + fileExtension
-                else:
-                    rep_file = rep_file + "." + fileExtension
-        else:
-            rep = None
-            rep_file = None
-            print("no representation found")
-        print("add compartment ", name, geom, rep, rep_file)
-        o = Compartment(
-            name,
-            None,
-            None,
-            None,
-            filename=geom,
-            object_name=rep,
-            object_filename=rep_file,
-        )
-        print("added compartment ", name)
-        env.addCompartment(o)
-        rsnodes = onode.getElementsByTagName("surface")
-
-        if len(rsnodes):
-            rSurf = Recipe(name=o.name + "_surf")
-            rsnodes = rsnodes[0]
-            ingredients_xmlfile = str(rsnodes.getAttribute("include"))
-            if ingredients_xmlfile:  # open the file and parse the ingredient:
-                # check if multiple include filename, aumngo',' in the path
-                liste_xmlfile = ingredients_xmlfile.split(",")
-                for xmlf in liste_xmlfile:
-                    xmlfile = autopack.retrieveFile(
-                        xmlf,
-                        # destination = self.name+os.sep+"recipe"+os.sep,
-                        cache="recipes",
-                    )
-                    if xmlfile:
-                        xmlinclude = parse(xmlfile).documentElement
-                        io_ingr.set_recipe_ingredient(xmlinclude, rSurf)
-            io_ingr.set_recipe_ingredient(rsnodes, rSurf)
-            o.setSurfaceRecipe(rSurf)
-        rinodes = onode.getElementsByTagName("interior")
-
-        if len(rinodes):
-            rMatrix = Recipe(name=o.name + "_int")
-            rinodes = rinodes[0]
-            ingredients_xmlfile = str(rinodes.getAttribute("include"))
-            if ingredients_xmlfile:  # open the file and parse the ingredient:
-                # check if multiple include filename, aumngo',' in the path
-                liste_xmlfile = ingredients_xmlfile.split(",")
-                for xmlf in liste_xmlfile:
-                    xmlfile = autopack.retrieveFile(
-                        xmlf,
-                        # destination = self.name+os.sep+"recipe"+os.sep,
-                        cache="recipes",
-                    )
-                    if xmlfile:
-                        xmlinclude = parse(xmlfile).documentElement
-                        io_ingr.set_recipe_ingredient(xmlinclude, rMatrix)
-            io_ingr.set_recipe_ingredient(rinodes, rMatrix)
-            o.setInnerRecipe(rMatrix)
-    # Go through all ingredient and setup the partner
-    env.loopThroughIngr(env.set_partners_ingredient)
-
-
 def load_JsonString(env, astring):
     """
     Setup the environment according the given json file.
@@ -1969,16 +1437,7 @@ def setupFromJsonDic(
         #        autopack.replace_path.extend(env.custom_paths)#keyWordPAth,valuePath
         autopack.updateReplacePath(env.custom_paths)
     autopack.current_recipe_path = env.current_path
-    options = env.jsondic["options"]
-    if len(options):
-        for k in env.OPTIONS:
-            if k == "gradients":
-                continue
-            if k in options:
-                setattr(env, k, options[k])
-        env.boundingBox = options["boundingBox"]
-        if None in env.boundingBox[0] or None in env.boundingBox[1]:
-            env.boundingBox = ([0, 0, 0], [1000, 1000, 1000])
+
     if "gradients" in env.jsondic:
         env.gradients = {}
         gradientsnode = env.jsondic["gradients"]
@@ -2010,7 +1469,9 @@ def setupFromJsonDic(
             for ing_name in sorted(ingrs_dic, key=sortkey):  # ingrs_dic:
                 # either xref or defined
                 ing_dic = ingrs_dic[ing_name]
-                ingr = io_ingr.makeIngredientFromJson(inode=ing_dic, recipe=env.name)
+                ingr = io_ingr.makeIngredientFromJson(
+                    env, inode=ing_dic, recipe=env.name
+                )
                 rCyto.addIngredient(ingr)
                 # setup recipe
             env.setExteriorRecipe(rCyto)
@@ -2045,16 +1506,6 @@ def setupFromJsonDic(
                 rep_file = ""
                 if "rep_file" in comp_dic:
                     rep_file = str(comp_dic["rep_file"])
-                # print(
-                #     "rep ?",
-                #     name,
-                #     geom,
-                #     gname,
-                #     rep,
-                #     rep_file,
-                #     (rep != "None" and len(rep) != 0 and rep != "" and rep == ""),
-                # )
-                #                print (len(rep),rep == '',rep=="",rep != "None",rep != "None" or len(rep) != 0)
                 if rep != "None" and len(rep) != 0 and rep != "" and rep != "":
                     rname = rep_file.split("/")[-1]
                     fileName, fileExtension = os.path.splitext(rname)
@@ -2067,19 +1518,10 @@ def setupFromJsonDic(
                 else:
                     rep = None
                     rep_file = None
-                o = Compartment(
-                    name,
-                    None,
-                    None,
-                    None,
-                    gname=gname,
-                    filename=geom,
-                    object_name=rep,
-                    object_filename=rep_file,
-                    meshType=mtype,
+                compartment = env.create_compartment(
+                    name, geom, gname, rep, rep_file, mtype
                 )
-                print("added compartment ", name)
-                env.addCompartment(o)
+                env.addCompartment(compartment)
                 if "surface" in comp_dic:
                     snode = comp_dic["surface"]
                     ingrs_dic = snode["ingredients"]
@@ -2090,11 +1532,11 @@ def setupFromJsonDic(
                             # either xref or defined
                             ing_dic = ingrs_dic[ing_name]
                             ingr = io_ingr.makeIngredientFromJson(
-                                inode=ing_dic, recipe=env.name
+                                env=env, inode=ing_dic, recipe=env.name
                             )
                             rSurf.addIngredient(ingr)
                             # setup recipe
-                        o.setSurfaceRecipe(rSurf)
+                        compartment.setSurfaceRecipe(rSurf)
                 if "interior" in comp_dic:
                     snode = comp_dic["interior"]
                     ingrs_dic = snode["ingredients"]
@@ -2105,11 +1547,11 @@ def setupFromJsonDic(
                             # either xref or defined
                             ing_dic = ingrs_dic[ing_name]
                             ingr = io_ingr.makeIngredientFromJson(
-                                inode=ing_dic, recipe=env.name
+                                env=env, inode=ing_dic, recipe=env.name
                             )
                             rMatrix.addIngredient(ingr)
                             # setup recipe
-                        o.setInnerRecipe(rMatrix)
+                        compartment.setInnerRecipe(rMatrix)
                     # Go through all ingredient and setup the partner
     env.loopThroughIngr(env.set_partners_ingredient)
     # restore env.molecules if any resuylt was loaded
@@ -2290,3 +1732,42 @@ def load_MixedasJson(env, resultfilename=None, transpose=True):
     except:  # noqa: E722
         pass
     return result, orgaresult, freePoint
+
+
+def save(
+    env,
+    setupfile,
+    useXref=None,
+    format_output="json",
+    kwds=None,
+    result=False,
+    grid=False,
+    packing_options=False,
+    indent=False,
+    quaternion=False,
+    transpose=False,
+    all_ingr_as_array=None,
+    compartments=None,
+):
+    if useXref is None:
+        useXref = env.useXref
+    if format_output == "json":
+        save_Mixed_asJson(
+            env,
+            setupfile,
+            useXref=useXref,
+            kwds=kwds,
+            result=result,
+            indent=indent,
+            grid=grid,
+            packing_options=packing_options,
+            quaternion=quaternion,
+            transpose=transpose,
+        )
+
+    elif format_output == "simularium":
+        save_as_simularium(env, setupfile, all_ingr_as_array, compartments)
+    elif format_output == "python":
+        save_asPython(env, setupfile, useXref=useXref)
+    else:
+        print("format output " + format_output + " not recognized (json,python)")
