@@ -1,6 +1,7 @@
 from cellpack.autopack.upy.colors import create_divergent_color_map_with_scaled_values
 import plotly.graph_objects as go
 import plotly.colors as pcolors
+import numpy
 
 
 class PlotlyAnalysis:
@@ -33,15 +34,26 @@ class PlotlyAnalysis:
             opacity=opacity,
         )
 
-    def add_square(self, radius, pos, color, opacity=1):
+    def add_square(self, side_length, pos, rotMat, color, opacity=1):
+        # side_length is the length of each side
+        x0 = -side_length[0][0] / 2.0
+        y0 = -side_length[0][1] / 2.0
+        x1 = side_length[0][0] / 2.0
+        y1 = side_length[0][1] / 2.0
+        # corner points of the cube top surface
+        point_array = [[x0, y0], [x1, y0], [x1, y1], [x0, y1]]
+        rotated_pts = self.transformPoints2D(pos, rotMat, point_array)
+        path_str = ""
+        for index, point_to_print in enumerate(rotated_pts):
+            if index == 0:
+                path_str += "M {0[0]} {0[1]} ".format(point_to_print)
+            else:
+                path_str += "L {0[0]} {0[1]} ".format(point_to_print)
+        path_str += "Z"
+
         self.plot.add_shape(
-            type="rect",
-            xref="x",
-            yref="y",
-            x0=pos[0] - radius,
-            y0=pos[1] - radius,
-            x1=pos[0] + radius,
-            y1=pos[1] + radius,
+            type="path",
+            path=path_str,
             line_color=PlotlyAnalysis.format_color(color),
             opacity=opacity,
         )
@@ -64,7 +76,12 @@ class PlotlyAnalysis:
                 if ingr.modelType == "Spheres":
                     self.add_circle(ingr.encapsulatingRadius, pos, ingr.color)
                 elif ingr.modelType == "Cube":
-                    self.add_square(ingr.encapsulatingRadius, pos, ingr.color)
+                    self.add_square(ingr.radii, pos, rot, ingr.color)
+                elif ingr.modelType == "Cylinders":
+                    length = ingr.length
+                    width = 2 * ingr.radii[0][0]
+                    side_lengths = [[width, length, 1.0]]
+                    self.add_square(side_lengths, pos, rot, ingr.color)
 
     def make_grid_heatmap(self, env):
         ids = []
@@ -111,3 +128,10 @@ class PlotlyAnalysis:
 
     def show(self):
         self.plot.show()
+
+    def transformPoints2D(self, trans, rot, points):
+        output = []
+        rot = numpy.array(rot)
+        for point in points:
+            output.append(numpy.matmul(rot[0:2, 0:2], point) + trans[0:2])
+        return output
